@@ -1,5 +1,8 @@
+# Standard imports
+from sqlalchemy import create_engine
+
 # Third-party imports
-from sqlalchemy import SQLAlchemy
+from ._sqlalchemy import SQLAlchemy
 
 
 class PostgresClient(SQLAlchemy):
@@ -15,4 +18,11 @@ class PostgresClient(SQLAlchemy):
                 username (str): Username for authentication/privileges
                 password (str): Password for authentication
         """
-        super().__init__(engine = "postgres", host = host, port = port, database = database, username = username, password = password)
\ No newline at end of file
+        super().__init__(engine = "postgres", host = host, port = port, database = database, username = username, password = password)
+        self.engine = create_engine(self.connection_string)
+
+
+    @property
+    def connection_string(self) -> str:
+        """ Returns the connection string """
+        return f"{self.engine}://{self.username}:{self.password}@{self.host}:{self.port}/{self.database}"
\ No newline at end of file
